@@ -248,13 +248,22 @@ enum OER_DEBUG_LEVELS {
 #define OER_SEEN 3
 #define OER_PERMBANS 25
 #define OER_LOGON_TIMEOUT 1800
+#define OER_BANVARS_AUTO_REJOIN 30
+#define OER_BANVARS_PART_REJOIN 600
+#define OER_BANVARS_PUBLIC_FLOOD 300
+#define OER_BANVARS_PUBLIC_FLOOD_REPEAT 600
+#define OER_BANVARS_BAD_WORD 3600
+#define OER_BANVARS_BAD_NICK 3600
+#define OER_BANVARS_NORMAL_BAN 3600
+#define OER_SAVE_INTERVAL 3600
+#define OER_ALLOWED_QUOTE_TIME_USEC 600000
+/* Define if you want to show server idle percentage */
+/* #undef OER_UPTIME_SHOW_IDLE */
 #define PUBMSG_FLOOD_LINES OER_PUBMSGS / 2
 #define PUBMSG_FLOOD_CHARS OER_PUBMSGS * 80
 #define PUBMSG_FLOOD_INTERVAL 60
 #define PUBMSG_FLOOD_REPEAT 3
 #define PUBMSG_FLOOD_REPEAT_EXPIRE 1800
-#define OER_SAVE_INTERVAL 3600
-#define OER_ALLOWED_QUOTE_TIME_USEC 600000
 #define TXT_BUFFER 1024
 /* this is the ircd buffer size */
 #define IRCD_BUFFER_LENGTH 512
@@ -278,7 +287,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-25, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-26, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -292,6 +301,16 @@ struct floodvars {
 	int chars;
 };
 
+struct banvars {
+	int auto_rejoin;
+	int part_rejoin;
+	int public_flood;
+	int public_flood_repeat;
+	int bad_word;
+	int bad_nick;
+	int normal_ban;
+};
+
 struct locked {
 	int locked;
 	int unlocked;
@@ -441,6 +460,7 @@ struct channel {
 	struct modeline *modelines;
 	struct locked locked;
         struct floodvars floodvars;
+        struct banvars banvars;
 	struct chanuser *nicks;
 	struct maskstruct *permbans;
 	struct maskstruct *nickbks;
