@@ -565,7 +565,7 @@ void parseirc(char *serveroutput)
 			oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->%s on %s by %s!%s\n", mode, channel, nick, host);
 		}
 		/* lame way to keep chanmodes, i need to code a proper modeline parser */
-		if(index(mode, (int)'p') != NULL || index(mode, (int)'s') != NULL || index(mode, (int)'i') != NULL || index(mode, (int)'t') != NULL || index(mode, (int)'n') != NULL || index(mode, (int)'m') != NULL || index(mode, (int)'l') != NULL || index(mode, (int)'k') != NULL) {
+		if(!isme(nick) && (index(mode, (int)'p') != NULL || index(mode, (int)'s') != NULL || index(mode, (int)'i') != NULL || index(mode, (int)'t') != NULL || index(mode, (int)'n') != NULL || index(mode, (int)'m') != NULL || index(mode, (int)'l') != NULL || index(mode, (int)'k') != NULL)) {
 			this->setchanmode = 1;			
 		}
 		i = 0;
@@ -1403,7 +1403,11 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "oer uptime: %s", uptimestring);
 		if(uptime(&uptime_seconds, &idle_seconds)) {
 			secondstostring(uptime_seconds, uptimestring, STRINGLEN);
+#ifdef OER_UPTIME_SHOW_IDLE
 			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", server uptime: %s (idle %.2f%%)", uptimestring, ((float)((float)idle_seconds/(float)uptime_seconds) * 100.0));
+#else
+			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", server uptime: %s", uptimestring);
+#endif
 			strncat(outstring, outstring2, WRITE_BUFFER_LENGTH - strlen(outstring));
 		}
 		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring);
